==> nucliadb_node_binding-3.1.0.post1295.tar.gz: nucliadb_node_binding-3.1.0.post1295/local_dependencies/nucliadb_core/src/lib.rs <==
// Copyright (C) 2021 Bosutech XXI S.L.
//
// nucliadb is offered under the AGPL v3.0 and as commercial software.
// For commercial licensing, contact us at info@nuclia.com.
//
// AGPL:
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU Affero General Public License as
// published by the Free Software Foundation, either version 3 of the
// License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU Affero General Public License for more details.
//
// You should have received a copy of the GNU Affero General Public License
// along with this program. If not, see <http://www.gnu.org/licenses/>.
//

pub mod fs_state;
pub mod merge;
pub mod metrics;
pub mod paragraphs;
pub mod query_language;
pub mod query_planner;
pub mod relations;
pub mod tantivy_replica;
pub mod texts;
pub mod vectors;

pub mod protos {
    pub use nucliadb_protos::prelude::*;
    pub use {prost, prost_types};
}

pub mod tracing {
    pub use tracing::*;
}

pub mod thread {
    pub use rayon::prelude::*;
    pub use rayon::*;
}

pub mod prelude {
    pub use crate::{node_error, read_rw_lock, write_rw_lock, Context, NodeResult};
}

use std::collections::HashMap;
use std::sync::{RwLock, RwLockReadGuard, RwLockWriteGuard};

pub use anyhow::{anyhow as node_error, Context, Error};
use nucliadb_protos::utils::ReleaseChannel;
use serde::{Deserialize, Serialize};

use crate::tantivy_replica::TantivyReplicaState;
pub type NodeResult<O> = anyhow::Result<O>;

#[derive(Clone, Copy, Serialize, Deserialize, Debug, PartialEq, Eq, Default)]
pub enum Channel {
    #[default]
    STABLE,
    EXPERIMENTAL,
}

impl From<i32> for Channel {
    fn from(value: i32) -> Self {
        match value {
            1 => Channel::EXPERIMENTAL,
            _ => Channel::STABLE,
        }
    }
}

impl From<Channel> for i32 {
    fn from(value: Channel) -> Self {
        match value {
            Channel::STABLE => ReleaseChannel::Stable as i32,
            Channel::EXPERIMENTAL => ReleaseChannel::Experimental as i32,
        }
    }
}

#[derive(Debug, Default)]
pub struct RawReplicaState {
    pub metadata_files: HashMap<String, Vec<u8>>,
    pub files: Vec<String>,
}

impl RawReplicaState {
    pub fn extend(&mut self, other: RawReplicaState) {
        self.metadata_files.extend(other.metadata_files);
        self.files.extend(other.files);
    }
}

pub enum IndexFiles {
    Tantivy(TantivyReplicaState),
    Other(RawReplicaState),
}

pub fn read_rw_lock<T: ?Sized>(rw_lock: &RwLock<T>) -> RwLockReadGuard<'_, T> {
    rw_lock.read().unwrap_or_else(|poisoned| poisoned.into_inner())
}

pub fn write_rw_lock<T: ?Sized>(rw_lock: &RwLock<T>) -> RwLockWriteGuard<'_, T> {
    rw_lock.write().unwrap_or_else(|poisoned| poisoned.into_inner())
}

==> nucliadb_node_binding-4.0.0.post1330.tar.gz: nucliadb_node_binding-4.0.0.post1330/local_dependencies/nucliadb_core/src/lib.rs <==
// Copyright (C) 2021 Bosutech XXI S.L.
//
// nucliadb is offered under the AGPL v3.0 and as commercial software.
// For commercial licensing, contact us at info@nuclia.com.
//
// AGPL:
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU Affero General Public License as
// published by the Free Software Foundation, either version 3 of the
// License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU Affero General Public License for more details.
//
// You should have received a copy of the GNU Affero General Public License
// along with this program. If not, see <http://www.gnu.org/licenses/>.
//

pub mod fs_state;
pub mod merge;
pub mod metrics;
pub mod paragraphs;
pub mod query_language;
pub mod query_planner;
pub mod relations;
pub mod tantivy_replica;
pub mod texts;
pub mod vectors;

pub mod protos {
    pub use nucliadb_protos::prelude::*;
    pub use {prost, prost_types};
}

pub mod tracing {
    pub use tracing::*;
}

pub mod thread {
    pub use rayon::prelude::*;
    pub use rayon::*;
}

pub mod prelude {
    pub use crate::{node_error, read_rw_lock, write_rw_lock, Context, NodeResult};
}

use std::collections::HashMap;
use std::sync::{RwLock, RwLockReadGuard, RwLockWriteGuard};

pub use anyhow::{anyhow as node_error, Context, Error};
use nucliadb_protos::utils::ReleaseChannel;
use serde::{Deserialize, Serialize};

use crate::tantivy_replica::TantivyReplicaState;
pub type NodeResult<O> = anyhow::Result<O>;

#[derive(Clone, Copy, Serialize, Deserialize, Debug, PartialEq, Eq, Default)]
pub enum Channel {
    #[default]
    STABLE,
    EXPERIMENTAL,
}

impl From<ReleaseChannel> for Channel {
    fn from(value: ReleaseChannel) -> Self {
        match value {
            ReleaseChannel::Experimental => Channel::EXPERIMENTAL,
            ReleaseChannel::Stable => Channel::STABLE,
        }
    }
}

impl From<Channel> for ReleaseChannel {
    fn from(value: Channel) -> Self {
        match value {
            Channel::STABLE => ReleaseChannel::Stable,
            Channel::EXPERIMENTAL => ReleaseChannel::Experimental,
        }
    }
}

#[derive(Debug, Default)]
pub struct RawReplicaState {
    pub metadata_files: HashMap<String, Vec<u8>>,
    pub files: Vec<String>,
}

impl RawReplicaState {
    pub fn extend(&mut self, other: RawReplicaState) {
        self.metadata_files.extend(other.metadata_files);
        self.files.extend(other.files);
    }
}

pub enum IndexFiles {
    Tantivy(TantivyReplicaState),
    Other(RawReplicaState),
}

pub fn read_rw_lock<T: ?Sized>(rw_lock: &RwLock<T>) -> RwLockReadGuard<'_, T> {
    rw_lock.read().unwrap_or_else(|poisoned| poisoned.into_inner())
}

pub fn write_rw_lock<T: ?Sized>(rw_lock: &RwLock<T>) -> RwLockWriteGuard<'_, T> {
    rw_lock.write().unwrap_or_else(|poisoned| poisoned.into_inner())
}
